==> chucker_flutter-1.0.0.tar.gz: lib/src/localization/localization.ur.dart <==
part of 'localization.dart';

const _ur = {
  'successRequest': 'کامیاب\nدرخواستیں',
  'failedRequests': 'ناکام\nدرخواستیں',
  'remainingRequests': 'باقی\nدرخواستیں',
  'singleDeletionTitle': 'مندرج اعداد و شمار کی تحذیف',
  'singleDeletionMessage':
      '''کیا آپ چنندہ اعداد و شمار کو حذف کرنا چاہتے ہیں؟''',
  'multipleDeletionTitle': 'مندرج اعداد و شمار کی تحذیف',
  'multipleDeletionMessage':
      '''کیا آپ چنندہ اعداد و شمار کو حذف کرنا چاہتے ہیں؟''',
  'noApiMessage': 'کوئی درخواست موجود نہیں',
  'attribute': 'صنف',
  'value': 'قدر',
  'copy': 'نقل کریں',
  'delete': 'حذف',
  'nA': 'موجود نہیں',
  'no': 'جی نہیں',
  'yes': 'جی ہاں',
  'showSearch': 'تلاش دکھائیں',
  'hideSearch': 'تلاش چھپائیں',
  'all': 'تمام',
  'settings': 'ترتیبات',
  'details': 'تفصیلات',
  'overview': 'جائزہ',
  'request': 'درخواست',
  'response': 'جواب',
  'notification': 'اطلاع',
  'show': 'دکھائیں',
  'notificationSettingDesc':
      '''اگر اجازت ہوگی تو آپ ہر درخواست کے آخر میں اطلاع پائیں گے''',
  'duration': 'دورانیہ',
  'durationSettingDesc': '''اطلاع اتنے سیکنڈز تک سامنے رہے گی''',
  'seconds': 'سیکنڈز',
  'alignment': 'سیدھ',
  'alignmentSettingDesc': '''اطلاع اس سیدھ میں سامنے آئے گی''',
  'apiListingScreen': 'تمام درخواستوں والا صفحہ',
  'selectedMethod': 'چنندہ Http Method',
  'selectedMethodDesc': '''یہ Http Method ہر بار آنے پر خود ہی چنا ہوا ہوگا''',
  'showRequestStats': 'اعداد و شمار دکھائیں',
  'showRequestStatsDesc': '''اگر اجازت ہوگی تو اعداد و شمار نظر آئیں گے''',
  'apiRequests': 'درخواستیں',
  'threshold': 'حد',
  'apis': 'درخواستیں',
  'apiSettingDesc': '''اس سے زیادہ درخواستیں آپ کے پاس محفوظ نہیں ہوں گی''',
  'apiSettingsImpInfo':
      '''اس کو دھیان سے اختیار کریں زیادہ ہونے کی صورت میں  آپ کی ڈیوائس کی Memory پر فرق پڑ سکتا ہے۔''',
  'deletionOfRequests': 'درخواستوں کی تحذیف',
  'showConfirmDialog': 'تصدیقی Dialogدکھائیں',
  'showDialogDesc':
      '''اگر اجازت ہوگی تو تحذیف سے پہلے تصدیقی Dialog ظاہر ہوگا''',
  'currentValue': 'موجودہ قدر: ',
  'language': 'زبان',
  'chuckerLanguage': 'Chucker زبان',
  'chuckerLanguageDesc': '''زبان کی تبدیل اگلی بار ظاہر ہوگی ''',
  'successRequestsWithSpace': 'کامیاب درخواستیں',
  'failedRequestsWithSpace': 'ناکام درخواستیں',
};

==> chucker_flutter-1.1.2.tar.gz: lib/src/localization/localization.ur.dart <==
part of 'localization.dart';

const _ur = {
  'successRequest': 'کامیاب\nدرخواستیں',
  'failedRequests': 'ناکام\nدرخواستیں',
  'remainingRequests': 'باقی\nدرخواستیں',
  'singleDeletionTitle': 'مندرج اعداد و شمار کی تحذیف',
  'singleDeletionMessage':
      '''کیا آپ چنندہ اعداد و شمار کو حذف کرنا چاہتے ہیں؟''',
  'multipleDeletionTitle': 'مندرج چنندہ اعداد و شمار کی تحذیف',
  'multipleDeletionMessage':
      '''کیا آپ چنندہ تمام اعداد و شمار کو حذف کرنا چاہتے ہیں؟''',
  'noApiMessage': 'کوئی درخواست موجود نہیں',
  'attribute': 'صنف',
  'value': 'قدر',
  'copy': 'نقل کریں',
  'delete': 'حذف',
  'nA': 'موجود نہیں',
  'no': 'جی نہیں',
  'yes': 'جی ہاں',
  'showSearch': 'تلاش دکھائیں',
  'hideSearch': 'تلاش چھپائیں',
  'all': 'تمام',
  'settings': 'ترتیبات',
  'details': 'تفصیلات',
  'overview': 'جائزہ',
  'request': 'درخواست',
  'response': 'جواب',
  'notification': 'اطلاع',
  'show': 'دکھائیں',
  'notificationSettingDesc':
      '''اگر اجازت ہوگی تو آپ ہر درخواست کے آخر میں اطلاع پائیں گے''',
  'duration': 'دورانیہ',
  'durationSettingDesc': '''اطلاع اتنے سیکنڈز تک سامنے رہے گی''',
  'seconds': 'سیکنڈز',
  'alignment': 'سیدھ',
  'alignmentSettingDesc': '''اطلاع اس سیدھ میں سامنے آئے گی''',
  'apiListingScreen': 'تمام درخواستوں والا صفحہ',
  'selectedMethod': 'چنندہ Http Method',
  'selectedMethodDesc': '''یہ Http Method ہر بار آنے پر خود ہی چنا ہوا ہوگا''',
  'showRequestStats': 'اعداد و شمار دکھائیں',
  'showRequestStatsDesc': '''اگر اجازت ہوگی تو اعداد و شمار نظر آئیں گے''',
  'apiRequests': 'API درخواستیں',
  'threshold': 'حد',
  'apis': 'درخواستیں',
  'apiSettingDesc': '''اس سے زیادہ درخواستیں آپ کے پاس محفوظ نہیں ہوں گی''',
  'apiSettingsImpInfo':
      '''اس کو دھیان سے اختیار کریں زیادہ ہونے کی صورت میں  آپ کی ڈیوائس کی Memory پر فرق پڑ سکتا ہے۔''',
  'deletionOfRequests': 'درخواستوں کی تحذیف',
  'showConfirmDialog': 'تصدیقی Dialogدکھائیں',
  'showDialogDesc':
      '''اگر اجازت ہوگی تو تحذیف سے پہلے تصدیقی Dialog ظاہر ہوگا''',
  'currentValue': 'موجودہ قدر: ',
  'language': 'زبان',
  'chuckerLanguage': 'Chucker زبان',
  'chuckerLanguageDesc': '''زبان کی تبدیل اگلی بار ظاہر ہوگی ''',
  'successRequestsWithSpace': 'کامیاب درخواستیں',
  'failedRequestsWithSpace': 'ناکام درخواستیں',
};
